==> scibeam-0.1.0.tar.gz: scibeam-0.1.0/setup.py <==
# setup.py --- 
# 
# Filename: setup.py
# Description: 
# 
# Author:    Yu Lu
# Email:     yulu@utexas.edu
# Github:    https://github.com/SuperYuLu 
# 
# Created: Sat Jul 21 10:46:04 2018 (-0500)
# Version: 
# Last-Updated: Sun Aug 19 18:12:09 2018 (-0500)
#           By: yulu
#     Update #: 71
# 

from setuptools import setup

with open("README.rst") as f:
    README = f.read()

setup(
    name = 'scibeam',
    version = '0.1.0',
    author = 'Yu Lu',
    author_email = 'yulu@utexas.edu',
    url = 'https://github.com/SuperYuLu/SciBeam',
    packages = ['scibeam', 'scibeam.tests'],
    license = 'LICENSE.txt',
    description = 'A scientific time series analyzing tool on beam measurement',
    long_description = README,
    #long_description_content_type='text/markdown',
    install_requires = ['numpy',
                        'pandas',
                        'scipy',
                        'matplotlib'],
    
    #test_suite = 'nose.collector',
    #test_suite = 'tests',
    #tests_require = ['nose'],

    classifiers = [
        'Programming Language :: Python :: 3.6',
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Science/Research',
        'Topic :: Scientific/Engineering :: Physics',
        'License :: OSI Approved :: MIT License',
        ],
    
    keywords = 'physics time-series data-analysis pandas',
    
    package_data = {'scibeam': ['data/examples/time_series_1D/single_time_series.lvm',
                                'data/examples/time_series_2D/*.lvm',
                                'data/test/time_series_1D/single_time_series.lvm',
                                'data/test/time_series_2D/*.lvm'
    ]},
)

==> scibeam-0.1.1.tar.gz: scibeam-0.1.1/setup.py <==
# setup.py --- 
# 
# Filename: setup.py
# Description: 
# 
# Author:    Yu Lu
# Email:     yulu@utexas.edu
# Github:    https://github.com/SuperYuLu 
# 
# Created: Sat Jul 21 10:46:04 2018 (-0500)
# Version: 
# Last-Updated: Wed Aug 22 11:51:24 2018 (-0500)
#           By: yulu
#     Update #: 85
# 

from setuptools import setup

with open("README.rst") as f:
    README = f.read()

setup(
    name = 'scibeam',
    version = '0.1.1', 
    author = 'Yu Lu',
    author_email = 'yulu@utexas.edu',
    url = 'https://github.com/SuperYuLu/SciBeam',
    packages = ['scibeam', 'scibeam.tests', 'scibeam.core', 'scibeam.util'],
    license = 'LICENSE.txt',
    description = 'Library for scientific time series dat aanalysis and visualization on beam measurement',
    long_description = README,
    #long_description_content_type='text/markdown',
    install_requires = ['numpy',
                        'pandas',
                        'scipy',
                        'matplotlib'],
    
    #test_suite = 'nose.collector',
    #test_suite = 'tests',
    #tests_require = ['nose'],

    classifiers = [
        'Programming Language :: Python :: 3.6',
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Science/Research',
        'Topic :: Scientific/Engineering :: Physics',
        'License :: OSI Approved :: MIT License',
        ],
    
    keywords = 'physics time-series data-analysis pandas',
    
    package_data = {'scibeam': ['data/examples/time_series_1D/single_time_series.lvm',
                                'data/examples/time_series_2D/*.lvm',
                                'data/test/time_series_1D/single_time_series.lvm',
                                'data/test/time_series_2D/*.lvm'
    ]},
)
